package net.sf.jack4j;

/*
Copyright (C) 2008 Ondrej Par

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation; either version 2.1 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

*/

/**
 * Convenient implementation of {@link JackTransportClient} that correctly
 * defines all callbacks.
 * 
 * <p>
 * Inherited classes still have to call
 * {@link JackClient#setDefaultThreadInitCallback()} and other necessary
 * <code>setDefaultXXXCallback</code> methods to ensure that the callbacks are
 * actually called.
 * 
 * @author repa
 */
public abstract class AbstractJackTransportClient extends JackTransportClient {

	/**
	 * Simply calls inherited constructor.
	 * 
	 * @see JackClient#JackClient(String, boolean, boolean, String)
	 */
	public AbstractJackTransportClient(String clientName, boolean useExactName, boolean canStartServer,
	        String serverName) throws JackException {
		super(clientName, useExactName, canStartServer, serverName);
	}

	/**
	 * Always returns true.
	 */
	@Override
	public boolean syncCallback(JackTransportState state, TransportPosition position) {
		return true;
	}

	/**
	 * Does nothing.
	 */
	@Override
	public void timebaseCallback(JackTransportState state, int nframes, TransportPosition pos, boolean newPos) {
		// noop
	}

	/**
	 * This implementation only returns 0.
	 * 
	 * @see net.sf.jack4j.JackClient#bufferSizeCallback(int)
	 */
	@Override
	public int bufferSizeCallback(int newBufferSize) throws Exception {
		return 0;
	}

	/**
	 * This implementation does nothing.
	 * 
	 * @see net.sf.jack4j.JackClient#clientRegistrationCallback(java.lang.String,
	 *      boolean)
	 */
	@Override
	public void clientRegistrationCallback(String clientName, boolean registered) throws Exception {
		// noop
	}

	/**
	 * This implementation does nothing.
	 * 
	 * @see net.sf.jack4j.JackClient#freewheelCallback(boolean)
	 */
	@Override
	public void freewheelCallback(boolean onoff) throws Exception {
		// noop
	}

	/**
	 * This implementation only returns 0.
	 * 
	 * @see net.sf.jack4j.JackClient#graphOrderCallback()
	 */
	@Override
	public int graphOrderCallback() throws Exception {
		return 0;
	}

	/**
	 * This implementation does nothing.
	 * 
	 * @see net.sf.jack4j.JackClient#portConnectCallback(long, long, boolean)
	 */
	@Override
	public void portConnectCallback(long portAId, long portBId, boolean connected) throws Exception {
		// noop
	}

	/**
	 * This implementation does nothing.
	 * 
	 * @see net.sf.jack4j.JackClient#portRegistrationCallback(long, boolean)
	 */
	@Override
	public void portRegistrationCallback(long portId, boolean registered) throws Exception {
		// noop
	}

	/**
	 * This implementation only returns 0.
	 * 
	 * @see net.sf.jack4j.JackClient#process(int)
	 */
	@Override
	public int process(int bufferSize) throws Exception {
		return 0;
	}

	/**
	 * This implementation only returns 0.
	 * 
	 * @see net.sf.jack4j.JackClient#sampleRateCallback(int)
	 */
	@Override
	public int sampleRateCallback(int newSampleRate) throws Exception {
		return 0;
	}

	/**
	 * This implementation does nothing.
	 * 
	 * @see net.sf.jack4j.JackClient#threadInitCallback()
	 */
	@Override
	public void threadInitCallback() throws Exception {
		// noop
	}

	/**
	 * This implementation only returns 0.
	 * 
	 * @see net.sf.jack4j.JackClient#xRunCallback()
	 */
	@Override
	public int xRunCallback() throws Exception {
		return 0;
	}

}
