package net.sf.jack4j;

/*
Copyright (C) 2008 Ondrej Par

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation; either version 2.1 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

*/

import java.util.EnumSet;
import java.util.Set;

/**
 * Java version of Jack enum <code>jack_position_bits_t</code>.
 * 
 * @author repa
 * 
 */
public enum JackPositionBit {
	POSITION_BBT {

		@Override
		protected int nativeIntValue() {
			return JackConstants.JackPositionBBT();
		}
	},
	POSITION_TIMECODE {

		@Override
		protected int nativeIntValue() {
			return JackConstants.JackPositionTimecode();
		}
	},
	BBT_FRAME_OFFSET {

		@Override
		protected int nativeIntValue() {
			return JackConstants.JackBBTFrameOffset();
		}
	},
	AUDIO_VIDEO_RATIO {

		@Override
		protected int nativeIntValue() {
			return JackConstants.JackAudioVideoRatio();
		}
	},
	VIDEO_FRAME_OFFSET {

		@Override
		protected int nativeIntValue() {
			return JackConstants.JackVideoFrameOffset();
		}
	},
	;

	private Integer cachedIntValue = null;

	protected abstract int nativeIntValue();

	/**
	 * Returns integer value of native constant corresponding to this enum
	 * value.
	 */
	public int intValue() {
		if (cachedIntValue == null) {
			cachedIntValue = nativeIntValue();
		}
		return cachedIntValue;
	}

	/**
	 * Encodes set of enum constants as <code>int</code>, by ORing their
	 * values together.
	 */
	public static int encode(Set<JackPositionBit> flags) {
		int result = 0;
		for (JackPositionBit flag : flags) {
			result |= flag.intValue();
		}
		return result;
	}

	/**
	 * Decodes <code>int</code> value as set of enum values.
	 * 
	 * <p>
	 * The <code>value</code> must be a result of ORing values of native enum
	 * constants.
	 * 
	 * @throws IllegalArgumentException
	 *             if the value contains unrecognized bits
	 */
	public static EnumSet<JackPositionBit> decode(final int value) {
		EnumSet<JackPositionBit> result = EnumSet.noneOf(JackPositionBit.class);
		int bits = value;

		for (JackPositionBit flag : JackPositionBit.values()) {
			if ((bits & flag.intValue()) != 0) {
				result.add(flag);
				bits ^= flag.intValue();
			}
		}

		if (bits != 0) {
			throw new IllegalArgumentException("Can't decode JackPositionBit from value " + value); //$NON-NLS-1$
		}

		return result;
	}
}
