package net.sf.jack4j;

import java.nio.ByteBuffer;

/*
Copyright (C) 2008 Ondrej Par

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation; either version 2.1 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

*/

/**
 * Allows access to readable or writable part of the {@link RingBuffer}, using
 * direct NIO buffers.
 * 
 * <p>
 * Instances can be created using
 * {@link RingBuffer#createReadVector(java.nio.ByteOrder)} and
 * {@link RingBuffer#createWriteVector(java.nio.ByteOrder)} methods.
 * 
 * <p>
 * This class allows you to manipulate contents of the ringbuffer, without
 * advancing read and write pointers (see
 * {@link RingBuffer#readAdvanceBytes(int)} and
 * {@link RingBuffer#writeAdvanceBytes(int)} methods if you want to advance that
 * pointers afterwards).
 * 
 * <p>
 * While this type of access is quite efficient in native code, it doesn't
 * perform well in Java, because the vector and the <code>java.nio.Buffer</code>
 * objects must be created again whenever the ringbuffer pointers are advanced.
 * 
 * <p>
 * The class contains one or two {@link ByteBuffer} objects; first of them is
 * never null (but may have zero capacity) and covers certain (readable or
 * writable) part of the native ringbuffer. If the second ByteBuffer is not
 * null, it covers additional part of the native ringbuffer.
 * 
 * <p>
 * <b>Warning:</b> whenever the read/write pointers of the ringbuffer are
 * advanced, the previously created instance of this class is not valid anymore
 * and must not be used.
 */
public class RingBufferVector {

	private final ByteBuffer firstBuffer;
	private final ByteBuffer secondBuffer;

	RingBufferVector(ByteBuffer firstBuffer, ByteBuffer secondBuffer) {
		this.firstBuffer = firstBuffer;
		this.secondBuffer = secondBuffer;
	}

	/**
	 * @return the firstBuffer
	 */
	public ByteBuffer getFirstBuffer() {
		return firstBuffer;
	}

	/**
	 * @return the secondBuffer
	 */
	public ByteBuffer getSecondBuffer() {
		return secondBuffer;
	}

}
