package net.sf.jack4j;

/*
Copyright (C) 2008 Ondrej Par

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation; either version 2.1 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

*/

/**
 * Allows access to Jack statistics information.
 * 
 * <p>
 * The Statistics object is always attached to a single {@link JackClient}
 * instance, and is only usable during the lifetime of the client.
 * 
 * @author repa
 * 
 */
public class Statistics {

	private final JackClient client;
	@SuppressWarnings("unused")
	private final long clientHandle;

	Statistics(JackClient client) {
		this.client = client;
		this.clientHandle = client.getClientHandle();
	}

	/**
	 * Returns the maximum delay reported by the back-end since startup or
	 * reset.
	 */
	public native float getMaxDelayedUsecs();

	/**
	 * Returns the delay in microseconds due to the most recent XRUN occurrence.
	 */
	public native float getXRunDelayedUsecs();

	/**
	 * Reset the maximum delay counter.
	 */
	public native void resetMaxDelayedUsecs();

	/**
	 * @return the client
	 */
	public JackClient getClient() {
		return client;
	}
}
